namespace IRF.ConsoleGuessGame
{   
    using System;
    using System.Diagnostics;
    using System.Globalization;
    using System.Reflection;
    using System.Resources;

    public static class Program
    {
        internal static GuessGame Game { get; private set; }
    
        public static void Main(string[] args)
        {
            // check command line arguments
            if (args == null || args.Length != 1)
            {
                Console.WriteLine(">ERROR: Improper parameters were supplied!");
                Console.WriteLine(">Usage: {0} sessionName",
			Process.GetCurrentProcess().ProcessName);
                
                return;
            }
                       
            // create a new game instance and start a new round
            Game = new GuessGame(args[0]);

            while (true)
            {
                Console.WriteLine(">Enter a new guess between 0-100:");

                string guessString = Console.ReadLine();

                try
                {
                    int guess = Int32.Parse(guessString);
                    GuessResult result = Game.Guess(guess);

                    switch (result)
                    {
                        case GuessResult.TooLow:
                            Console.WriteLine(">Too low!");
                            break;
                        case GuessResult.TooHigh:
                            Console.WriteLine(">Too high!");
                            break;
                        case GuessResult.Success:
                            Console.WriteLine(">You win! Starting a new match...");
                            Game.NewRound();
                            break;                            
                        case GuessResult.WrongInput:
                            Console.WriteLine(">ERROR: Enter a number between 0-100!");
                            break;
                        default:
                            break;
                    }
                }
                catch (Exception)
                {
                    Console.WriteLine(">ERROR: Enter just a number, could not convert input to number");
                }
            }
        }
    }
}
